geometrex v0.1.1 Geometry
Documentation for Geometry.
Link to this section Summary
Functions
First, given two points called point A and point B. Calculate Equilateral Triangle with following algorithm:compared only distance for point A , point B.and point C. not using middle point for point A, point B
Link to this section Functions
Link to this function
mkEquilateralTriangle(t1, t2)
First, given two points called point A and point B. Calculate Equilateral Triangle with following algorithm:compared only distance for point A , point B.and point C. not using middle point for point A, point B.
Examples
iex> Geometry.mkEquilateralTriangle Point.new(1, 0), Point.new(0, 0)
[
%Point{x: 0.5000000010362837, y: 0.8660254031861399},
%Point{x: 0.5000000010362837, y: -0.8660254031861399}
]